==> neo4j-fulltext-index-3.5.33-sources.jar: org/neo4j/kernel/api/impl/fulltext/WritableFulltextIndex.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.api.impl.fulltext;

import java.io.IOException;

import org.neo4j.kernel.api.impl.index.WritableAbstractDatabaseIndex;

class WritableFulltextIndex extends WritableAbstractDatabaseIndex<LuceneFulltextIndex,FulltextIndexReader> implements DatabaseFulltextIndex
{
    private final IndexUpdateSink indexUpdateSink;

    WritableFulltextIndex( IndexUpdateSink indexUpdateSink, LuceneFulltextIndex fulltextIndex )
    {
        super( fulltextIndex );
        this.indexUpdateSink = indexUpdateSink;
    }

    @Override
    public String toString()
    {
        return luceneIndex.toString();
    }

    @Override
    protected void commitLockedFlush() throws IOException
    {
        indexUpdateSink.awaitUpdateApplication();
        super.commitLockedFlush();
    }

    @Override
    protected void commitLockedClose() throws IOException
    {
        indexUpdateSink.awaitUpdateApplication();
        super.commitLockedClose();
    }

    @Override
    public TransactionStateLuceneIndexWriter getTransactionalIndexWriter() throws IOException
    {
        return new TransactionStateLuceneIndexWriter( luceneIndex );
    }
}

==> neo4j-fulltext-index-4.1.0-sources.jar: org/neo4j/kernel/api/impl/fulltext/WritableFulltextIndex.java <==
/*
 * Copyright (c) 2002-2020 "Neo4j,"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.api.impl.fulltext;

import java.io.IOException;

import org.neo4j.kernel.api.impl.index.WritableAbstractDatabaseIndex;

class WritableFulltextIndex extends WritableAbstractDatabaseIndex<LuceneFulltextIndex,FulltextIndexReader>
{
    private final IndexUpdateSink indexUpdateSink;

    WritableFulltextIndex( IndexUpdateSink indexUpdateSink, LuceneFulltextIndex fulltextIndex )
    {
        super( fulltextIndex );
        this.indexUpdateSink = indexUpdateSink;
    }

    @Override
    public String toString()
    {
        return luceneIndex.toString();
    }

    @Override
    protected void commitLockedFlush() throws IOException
    {
        indexUpdateSink.awaitUpdateApplication();
        super.commitLockedFlush();
    }

    @Override
    protected void commitLockedClose() throws IOException
    {
        indexUpdateSink.awaitUpdateApplication();
        super.commitLockedClose();
    }
}
